# Mach3_Cli

Recursively parse and index subtitle text for future use.


### Installation

    $ pip3 install mach3_cli


### Usage

To use it:

    $ mach3 --help


### Open-source code used:

* SQLAlchemy

* * <http://sqlalchemy.org>

* python-ass: A library for parsing and manipulating Advanced SubStation Alpha subtitle files.

  * https://github.com/rfw/python-ass
